summaryrefslogtreecommitdiff
path: root/source4/torture/drs/python/delete_object.py
diff options
context:
space:
mode:
Diffstat (limited to 'source4/torture/drs/python/delete_object.py')
-rw-r--r--source4/torture/drs/python/delete_object.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/source4/torture/drs/python/delete_object.py b/source4/torture/drs/python/delete_object.py
index 0cf648f5a0..2936a5717f 100644
--- a/source4/torture/drs/python/delete_object.py
+++ b/source4/torture/drs/python/delete_object.py
@@ -77,7 +77,7 @@ class DrsDeleteObjectTestCase(samba.tests.TestCase):
self.config_dn = self.info_dc1["configurationNamingContext"][0]
self.forest_level = int(self.info_dc1["forestFunctionality"][0])
# we will need DCs DNS names for 'net drs' command
self.dnsname_dc1 = self.info_dc1["dnsHostName"][0]
self.dnsname_dc2 = self.info_dc2["dnsHostName"][0]
@@ -127,13 +127,13 @@ class DrsDeleteObjectTestCase(samba.tests.TestCase):
def _net_drs_replicate(self, DC, fromDC):
# find out where is net command
- net_cmd = os.path.abspath("./bin/net")
+ samba_tool_cmd = os.path.abspath("./bin/samba-tool")
# make command line credentials string
creds = samba.tests.cmdline_credentials
cmd_line_auth = "-U%s/%s%%%s" % (creds.get_domain(),
creds.get_username(), creds.get_password())
- # bin/net drs replicate <Dest_DC_NAME> <Src_DC_NAME> <Naming Context>
- cmd_line = "%s drs replicate %s %s %s %s" % (net_cmd, DC, fromDC,
+ # bin/samba-tool drs replicate <Dest_DC_NAME> <Src_DC_NAME> <Naming Context>
+ cmd_line = "%s drs replicate %s %s %s %s" % (samba_tool_cmd, DC, fromDC,
self.domain_dn, cmd_line_auth)
ret = os.system(cmd_line)
self.assertEquals(ret, 0, "Replicating %s from %s has failed!" % (DC, fromDC))
@@ -77,7 +77,7 @@ class DrsDeleteObjectTestCase(samba.tests.TestCase):
self.config_dn = self.info_dc1["configurationNamingContext"][0]
self.forest_level = int(self.info_dc1["forestFunctionality"][0])
- # we will need DCs DNS names for 'net drs' command
+ # we will need DCs DNS names for 'samba-tool drs' command
self.dnsname_dc1 = self.info_dc1["dnsHostName"][0]
self.dnsname_dc2 = self.info_dc2["dnsHostName"][0]